@@ -101,6 +101,7 @@ namespace BibTeX
         {"ae", 0x00E6},
         {"OE", 0x0152},
         {"oe", 0x0153},
+        {"ldots", 0x2026},
         {"L", 0x0141},
         {"l", 0x0142},
         {"grqq", 0x201C},
@@ -240,7 +241,14 @@ namespace BibTeX
 
     static const int commandmappingdatalatexcount = sizeof( commandmappingdatalatex ) / sizeof( commandmappingdatalatex[ 0 ] ) ;
 
-    const char *expansionsCmd[] = {"\\{\\\\%1\\}", "\\\\%1\\{\\}", "\\\\%1"};
+    /** Command can be either
+        (1) {embraced}
+        (2) delimited by {},
+        (3) <space>, line end,
+        (4) \following_command (including \<space>, which must be maintained!),
+        (5) } (end of entry or group)
+     **/
+    const char *expansionsCmd[] = {"\\{\\\\%1\\}", "\\\\%1\\{\\}", "\\\\%1(\\n|\\r|\\\\|\\})", "\\\\%1\\s"};
     static const  int expansionscmdcount = sizeof( expansionsCmd ) / sizeof( expansionsCmd[0] );
 
     static const struct EncoderLaTeXModCharMapping
@@ -757,6 +765,8 @@ namespace BibTeX
                 CharMappingItem charMappingItem;
                 charMappingItem.regExp = QRegExp( QString( expansionsCmd[j] ).arg( commandmappingdatalatex[i].letters ) );
                 charMappingItem.unicode = QChar( commandmappingdatalatex[i].unicode );
+                if ( charMappingItem.regExp.numCaptures() > 0 )
+                    charMappingItem.unicode += QString( "\\1" );
                 charMappingItem.latex = QString( "{\\%1}" ).arg( commandmappingdatalatex[i].letters );
                 m_charMapping.append( charMappingItem );
             }
