@@ -62,7 +62,7 @@ namespace BibTeX
         struct CharMappingItem
         {
             QRegExp regExp;
-            QChar unicode;
+            QString unicode;
             QString latex;
         };
 
