@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2004-2008 by Thomas Fischer                             *
+*   Copyright (C) 2004-2009 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -68,12 +68,29 @@ namespace BibTeX
         return new Entry( this );
     }
 
+    bool Entry::equals( const Entry &other )
+    {
+        if ( other.id().compare( id() ) != 0 )
+            return false;
+
+        for ( EntryFields::iterator it = m_fields.begin(); it != m_fields.end(); it++ )
+        {
+            EntryField *field1 = *it;
+            EntryField *field2 = other.getField( field1->fieldTypeName() );
+
+            if ( field2 == NULL || field1->value() == NULL || field2->value() == NULL || field1->value()->text().compare( field2->value()->text() ) != 0 )
+                return false;
+        }
+
+        return true;
+    }
+
     QString Entry::text() const
     {
         QString result = "Id: ";
         result.append( m_id ).append( "  (" ).append( entryTypeString() ).append( ")\n" );
 
-        for ( EntryFields::const_iterator it = m_fields.begin(); it != m_fields.end(); it++ )
+        for ( EntryFields::ConstIterator it = m_fields.begin(); it != m_fields.end(); it++ )
         {
             result.append(( *it )->fieldTypeName() ).append( ": " );
             result.append(( *it )->value()->text() ).append( "\n" );
@@ -149,40 +166,46 @@ namespace BibTeX
             delete[] hits;
 
             /** return success depending on filter type and number of hits */
-            return ( filterType == ftAnyWord && hitCount > 0 || filterType == ftEveryWord && hitCount == words.count() );
+            return (( filterType == ftAnyWord && hitCount > 0 ) || ( filterType == ftEveryWord && hitCount == words.count() ) );
         }
     }
 
     QStringList Entry::urls() const
     {
         QStringList result;
-        QString fieldNames[] = {"localfile", "pdf", "ps", "postscript", "doi", "url", "howpublished", "ee", "biburl"};
+        const QString fieldNames[] = {"localfile", "pdf", "ps", "postscript", "doi", "url", "howpublished", "ee", "biburl", "note"};
+        const int fieldNamesCount = sizeof( fieldNames ) / sizeof( fieldNames[0] );
 
-        for ( unsigned int i = 0; i < sizeof( fieldNames ) / sizeof( fieldNames[0] ); i++ )
-        {
-            EntryField * field = getField( fieldNames[ i ] );
-            if (( field && !field->value() ->items.isEmpty() ) )
+        for ( int j = 1; j < 5 ; ++j ) /** there may be variants such as url3 or doi2 */
+            for ( int i = 0; i < fieldNamesCount; i++ )
             {
-                PlainText *plainText = dynamic_cast<PlainText*>( field->value()->items.first() );
-                if ( plainText != NULL )
+                QString fieldName = fieldNames[i];
+                /** field names should be like url, url2, url3, ... */
+                if ( j > 1 ) fieldName.append( QString::number( j ) );
+
+                EntryField * field = getField( fieldName );
+                if (( field && !field->value()->items.isEmpty() ) )
                 {
-                    QString plain = plainText->text();
-                    int urlPos = plain.find( "\\url{", 0, FALSE );
-                    if ( urlPos > -1 )
+                    PlainText *plainText = dynamic_cast<PlainText*>( field->value()->items.first() );
+                    if ( plainText != NULL )
                     {
-                        plain = plain.mid( urlPos + 5 );
-                        urlPos = plain.find( "}", 0, FALSE );
-                        if ( urlPos > 0 )
-                            plain = plain.left( urlPos - 1 );
+                        QString plain = plainText->text();
+                        int urlPos = plain.find( "\\url{", 0, FALSE );
+                        if ( urlPos > -1 )
+                        {
+                            plain = plain.mid( urlPos + 5 );
+                            urlPos = plain.find( "}", 0, FALSE );
+                            if ( urlPos > 0 )
+                                plain = plain.left( urlPos - 1 );
+                        }
+
+                        if ( fieldNames[ i ] == "doi" && !plain.startsWith( "http", FALSE ) )
+                            plain.prepend( "http://dx.doi.org/" );
+
+                        result.append( plain );
                     }
-
-                    if ( fieldNames[ i ] == "doi" && !plain.startsWith( "http", FALSE ) )
-                        plain.prepend( "http://dx.doi.org/" );
-
-                    result.append( plain );
                 }
             }
-        }
 
         return result;
     }
@@ -240,12 +263,12 @@ namespace BibTeX
         return FALSE;
     }
 
-    Entry::EntryFields::const_iterator Entry::begin() const
+    Entry::EntryFields::ConstIterator Entry::begin() const
     {
         return m_fields.constBegin();
     }
 
-    Entry::EntryFields::const_iterator Entry::end() const
+    Entry::EntryFields::ConstIterator Entry::end() const
     {
         return m_fields.constEnd();
     }
@@ -270,11 +293,11 @@ namespace BibTeX
         m_entryTypeString = other->m_entryTypeString;
         m_id = other->m_id;
         clearFields();
-        for ( EntryFields::const_iterator it = other->m_fields.begin(); it != other->m_fields.end(); it++ )
+        for ( EntryFields::ConstIterator it = other->m_fields.begin(); it != other->m_fields.end(); it++ )
             m_fields.append( new EntryField( *it ) );
     }
 
-    void Entry::merge( BibTeX::Entry *other, bool forceAdding )
+    void Entry::merge( BibTeX::Entry *other, MergeSemantics mergeSemantics )
     {
         for ( EntryFields::iterator it = other->m_fields.begin(); it != other->m_fields.end(); it++ )
         {
@@ -283,14 +306,16 @@ namespace BibTeX
             QString otherFieldTypeName = otherField->fieldTypeName();
             EntryField *thisField = otherFieldType != EntryField::ftUnknown ? getField( otherFieldType ) : getField( otherFieldTypeName );
 
-            if ( thisField != NULL && !forceAdding ) continue;
-
-            if ( thisField != NULL )
+            if ( thisField == NULL )
+            {
+                m_fields.append( otherField );
+            }
+            else if ( otherField->value()->text() == thisField->value()->text() && mergeSemantics == msForceAdding )
             {
                 otherFieldTypeName.prepend( "OPT" );
                 otherField->setFieldType( EntryField::ftUnknown, otherFieldTypeName );
+                m_fields.append( otherField );
             }
-            m_fields.append( otherField );
         }
     }
 
