@@ -217,10 +217,10 @@ namespace BibTeX
         if ( !comment->useCommand() )
         {
             QString text = comment->text() ;
-            escapeLaTeXChars( text );
 
             if ( m_encoding == "latex" )
                 text = EncoderLaTeX::currentEncoderLaTeX() ->encode( text );
+            fixLaTeXChars( text, false );
 
             QStringList commentLines = QStringList::split( '\n', text );
             for ( QStringList::Iterator it = commentLines.begin(); it != commentLines.end(); it++ )
@@ -232,10 +232,11 @@ namespace BibTeX
         else
         {
             QString text = comment->text() ;
-            escapeLaTeXChars( text );
 
             if ( m_encoding == "latex" )
                 text = EncoderLaTeX::currentEncoderLaTeX() ->encode( text );
+            fixLaTeXChars( text, false );
+
             writeString( device, QString( "@%1{%2}\n\n" ).arg( applyKeywordCasing( "Comment" ) ).arg( text ) );
         }
         return TRUE;
@@ -360,6 +361,31 @@ namespace BibTeX
                         v = ( *it )->lastName();
                         if ( !v.isEmpty() )
                         {
+                            /** Multi-part surnames (such as "Garcia Marquez") have to be enquoted.
+                              * However, "von"-Parts (as in "von Hofmannsthal") must _not_ be enquoted.
+                              * Examples:
+                              * -- Robson de Souza
+                              * -- Hartmann von der Tann
+                              * -- Ronaldo de {Assis Moreira} ("Ronaldo de Assis Moreira" works as well)
+                              * -- Ailton {Goncalves da Silva}
+                              * -- Gloria von {Thurn und Taxis}
+                              * Thus we split the von-Parts from the surname (= everything after the first upcase char).
+                              * FIXME: Make the personContainer aware of von-Parts and jr-Parts, instead.
+                              */
+                            QStringList list = QStringList::split(" ", v);
+                            QString von;
+                            for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
+                                QString str = *it;
+                                if (str != "others" && str[0].category() == QChar::Letter_Lowercase) {
+                                    von += *it;
+                                    von += " ";
+                                } else
+                                    break;
+                            }
+                            if (!von.isEmpty()) {
+                                text.append( von );
+                                v = v.right(v.length() - von.length());
+                            }
                             bool requiresQuoting = requiresPersonQuoting( v, TRUE );
                             if ( requiresQuoting ) text.append( "{" );
                             text.append( v );
@@ -368,11 +394,11 @@ namespace BibTeX
                     }
                 }
 
-                escapeLaTeXChars( text );
-
                 if ( m_encoding == "latex" )
                     text = encoder->encodeSpecialized( text, fieldType );
 
+                fixLaTeXChars( text, fieldType == EntryField::ftURL );
+
                 /** if the text to save contains a quote char ("),
                   * force string delimiters to be curly brackets,
                   * as quote chars as string delimiters would result
@@ -393,9 +419,48 @@ namespace BibTeX
         return result;
     }
 
-    void FileExporterBibTeX::escapeLaTeXChars( QString &text )
+    void FileExporterBibTeX::fixLaTeXChars( QString &text, bool verbatim )
     {
-        text.replace( "&", "\\&" );
+        if ( verbatim )
+        {
+            /** for verbatim cases, remove all backslash quotings */
+            text.replace( "\\&", "&" ).replace( "\\#", "#" ).replace( "\\_", "_" ).replace( "\\%", "%" );
+        }
+        else
+        {
+            /** in the first phase, add backslashes before special characters to be protected */
+            /** Use regular expressions to replace e.g. "e&" by "e\&" */
+            const char protect[] = {'&', '#', '_', '%'};
+            const QString prefix = "([^\\\\])";
+            for ( int i = sizeof( protect ) / sizeof( protect[0] ) - 1; i >= 0; --i )
+            {
+                QRegExp rx = QRegExp( prefix + protect[i] );
+                int pos = -1;
+                while (( pos = rx.search( text, pos + 1 ) ) >= 0 )
+                {
+                    text.replace( rx.cap( 1 ) + protect[i], rx.cap( 1 ) + "\\" + protect[i] );
+                }
+                /** special case at start of line */
+                text.replace( QRegExp( QString( "^" ) + protect[i] ), QString( "\\" ) + protect[i] );
+            }
+
+            /** handle special verbatim environment \url{..} by removing backslashes added just above */
+            int pos = -1;
+            while (( pos = text.find( "\\url{", pos + 1 ) ) >= 0 )
+            {
+                int p2 = pos + 5;
+                int counter = 1;
+                while ( counter > 0 )
+                {
+                    if ( text[p2] == '{' )++counter;
+                    else if ( text[p2] == '}' )--counter;
+                    ++p2;
+                }
+                QString text2 = text.mid( pos + 5, p2 - pos - 6 );
+                fixLaTeXChars( text2, true );
+                text = text.left( pos + 5 ) + text2 + text.mid( p2 - 1 );
+            }
+        }
     }
 
     QString FileExporterBibTeX::applyKeywordCasing( const QString &keyword )
@@ -412,14 +477,18 @@ namespace BibTeX
     bool FileExporterBibTeX::requiresPersonQuoting( const QString &text, bool isLastName )
     {
         if ( isLastName && !text.contains( " " ) )
+            /** Last name contains NO spaces, no quoting necessary */
             return FALSE;
         else if ( !isLastName && !text.contains( " and " ) )
+            /** First name contains no " and " no quoting necessary */
             return FALSE;
         else if ( text[0] != '{' || text[text.length()-1] != '}' )
+            /** as either last name contains spaces or first name contains " and " and there is no protective quoting yet, there must be a protective quoting added */
             return TRUE;
 
+        /** check for cases like "{..}..{..}", which must be surrounded with a protective quoting, too */
         int bracketCounter = 0;
-        for ( int i = text.length() - 1;i >= 0;--i )
+        for ( int i = text.length() - 1; i >= 0; --i )
         {
             if ( text[i] == '{' )
                 ++bracketCounter;
