@@ -77,7 +77,7 @@ namespace BibTeX
 
         QString valueToString( const Value *value, const EntryField::FieldType fieldType = EntryField::ftUnknown );
 
-        void escapeLaTeXChars( QString &text );
+        void fixLaTeXChars( QString &text, bool verbatim );
         QString applyKeywordCasing( const QString &keyword );
         bool requiresPersonQuoting( const QString &text, bool isLastName );
         void addProtectiveCasing( QString &text );
