@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2004-2008 by Thomas Fischer                             *
+*   Copyright (C) 2004-2009 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -45,6 +45,7 @@ namespace BibTeX
 
     bool FileExporterPDF::save( QIODevice* iodevice, const File* bibtexfile, QStringList *errorLog )
     {
+        m_mutex.lock();
         bool result = FALSE;
         m_embeddedFileList.clear();
         if ( m_embedFiles )
@@ -65,11 +66,13 @@ namespace BibTeX
         if ( result )
             result = generatePDF( iodevice, errorLog );
 
+        m_mutex.unlock();
         return result;
     }
 
     bool FileExporterPDF::save( QIODevice* iodevice, const Element* element, QStringList *errorLog )
     {
+        m_mutex.lock();
         bool result = FALSE;
         m_embeddedFileList.clear();
         if ( m_embedFiles )
@@ -87,6 +90,7 @@ namespace BibTeX
         if ( result )
             result = generatePDF( iodevice, errorLog );
 
+        m_mutex.unlock();
         return result;
     }
 
@@ -124,12 +128,14 @@ namespace BibTeX
             QTextStream ts( &latexFile );
             ts.setEncoding( QTextStream::UnicodeUTF8 );
             ts << "\\documentclass{article}\n";
+            if ( kpsewhich( "t2aenc.def" ) &&  kpsewhich( "t2aenc.dfu" ) &&  kpsewhich( "t1enc.dfu" ) )
+                ts << "\\usepackage[T1,T2A]{fontenc}\n";
             ts << "\\usepackage[" << m_latexLanguage << "]{babel}\n";
             if ( kpsewhich( "hyperref.sty" ) )
                 ts << "\\usepackage[pdfproducer={KBibTeX: http://www.t-fischer.net/kbibtex/},pdftex]{hyperref}\n";
             else if ( kpsewhich( "url.sty" ) )
                 ts << "\\usepackage{url}\n";
-            if ( kpsewhich( "apacite.sty" ) )
+            if ( m_latexBibStyle.startsWith( "apacite" ) && kpsewhich( "apacite.sty" ) )
                 ts << "\\usepackage[bibnewpage]{apacite}\n";
             if ( m_embedFiles )
                 ts << "\\usepackage{embedfile}\n";
