@@ -29,8 +29,9 @@
 
 namespace KBibTeX
 {
-    const QStringList IdSuggestions::smallWords = QStringList::split( '|', "and|on|in|the|of|at|a|an|with|for|from" );
     const QRegExp IdSuggestions::unwantedChars( "\\s|['\"$\\\\{}:-,]+" );
+    const QChar IdSuggestions::asciiizeSource[] = { QChar( 0x00e4 ), QChar( 0x00f6 ), QChar( 0x00fc ), QChar( 0x00c4 ), QChar( 0x00d6 ), QChar( 0x00dc ), QChar( 0x00e0 ), QChar( 0x00e8 ), QChar( 0x00f2 ), QChar( 0x00f9 ), QChar( 0x00c0 ), QChar( 0x00c8 ), QChar( 0x00d2 ), QChar( 0x00d9 ), QChar( 0x00e1 ), QChar( 0x00e9 ), QChar( 0x00fa ), QChar( 0x00c1 ), QChar( 0x00c9 ), QChar( 0x00d3 ), QChar( 0x00da ), QChar( 0x00e2 ), QChar( 0x00ea ), QChar( 0x00f4 ), QChar( 0x00fb ), QChar( 0x00c2 ), QChar( 0x00ca ), QChar( 0x00d4 ), QChar( 0x00db ), QChar( 0x00df ), QChar( 0x00e7 ), QChar( 0x00e6 ), QChar( 0x00c6 ), QChar( 0x0153 ), QChar( 0x0152 ), QChar( 0x00e5 ), QChar( 0x00c5 ), QChar( 0x00f8 ), QChar( 0x00d8 ), QChar( 0x00f1 ) };
+    const QString IdSuggestions::asciiizeTarget[] = { "ae", "oe", "ue", "Ae", "Oe", "Ue", "a", "e", "o", "u", "A", "E", "O", "U", "a", "e", "u", "A", "E", "O", "U", "a", "e", "o", "u", "A", "E", "O", "U", "ss", "c", "ae", "Ae", "oe", "Oe", "a", "A", "oe", "Oe", "n" };
 
     IdSuggestions::IdSuggestions()
     {
@@ -44,7 +45,7 @@ namespace KBibTeX
     }
 
     /**
-    * Determine list of authors for a given entry
+    * Determine list of authors or editors for a given entry
     */
     QStringList IdSuggestions::authorsLastName( BibTeX::Entry *entry )
     {
@@ -53,7 +54,15 @@ namespace KBibTeX
         /** retrieve field holding authors information for entry */
         BibTeX::EntryField *field = entry->getField( BibTeX::EntryField::ftAuthor );
         if ( field == NULL )
-            return result; /** no author field available */
+        {
+            /** no author field available, try editor
+                patch by Jurgen Spitzmuller <juergen.sp@t-online.de> */
+            field = entry->getField( BibTeX::EntryField::ftEditor );
+            if ( field == NULL )
+            {
+                return result; /** neither author nor editor available */
+            }
+        }
 
         /** fetch container holding list of author names */
         BibTeX::PersonContainer *personContainer = field != NULL ? dynamic_cast<BibTeX::PersonContainer*>( field->value()->items.isEmpty() ? NULL : field->value()->items.first() ) : NULL;
@@ -62,18 +71,24 @@ namespace KBibTeX
 
         /** iterate through container and fetch each author's last name */
         for ( QValueList<BibTeX::Person*>::ConstIterator it = personContainer->persons.begin(); it != personContainer->persons.end(); ++it )
-            result.append(( *it )->lastName().replace( Settings::noIdChars, "" ) );
+        {
+            result.append(( *it )->lastName() );
+        }
 
         return result;
     }
 
     /**
-    * Normalize a given text by removing spaces or other unwanted characters
+    * Normalize a given text by removing spaces or other unwanted characters,
+    * replace some accented and special characters by plain ASCII transliterations
     */
     QString IdSuggestions::normalizeText( const QString& text )
     {
+        const unsigned int numAsciiize = sizeof( asciiizeSource ) / sizeof( asciiizeSource[0] );
         QString result = text;
-        result = result.remove( unwantedChars );
+        for ( unsigned int i = 0; i < numAsciiize; ++i )
+            result.replace( asciiizeSource[i], asciiizeTarget[i] );
+        result = result.remove( unwantedChars ).replace( Settings::noIdChars, "" );
 
         return result;
     }
@@ -133,7 +148,7 @@ namespace KBibTeX
         if ( valueItem == NULL )
             return QString::null; /** no value item found or is empty */
 
-        return valueItem->text().replace( Settings::noIdChars, "" );
+        return valueItem->text();
     }
 
     QStringList IdSuggestions::createSuggestions( BibTeX::File *file, BibTeX::Entry *entry )
@@ -279,10 +294,12 @@ namespace KBibTeX
     QString IdSuggestions::translateTitleToken( BibTeX::Entry *entry, const QString& token, bool removeSmallWords )
     {
         struct IdSuggestionTokenInfo tti = evalToken( token );
+        Settings * settings = Settings::self();
+        const QStringList smallWords = settings->idSuggestions_smallWords;
 
         QString result;
         bool first = TRUE;
-        QStringList titleWords = QStringList::split( QRegExp( "\\s+" ), extractTitle( entry ).replace( QRegExp( "[\\\\{}]+" ), "" ) );
+        QStringList titleWords = QStringList::split( QRegExp( "\\s+" ), extractTitle( entry ) );
         for ( QStringList::ConstIterator it = titleWords.begin(); it != titleWords.end(); ++it )
         {
             if ( first )
@@ -303,6 +320,7 @@ namespace KBibTeX
         return result;
     }
 
+    /** convert a formatting string into a human readable version (even translated) */
     QString IdSuggestions::formatStrToHuman( const QString& formatStr )
     {
         bool first = TRUE;
