@@ -54,12 +54,15 @@ namespace KBibTeX
         enum Authors {aAll, aOnlyFirst, aNotFirst};
 
         static const QRegExp unwantedChars;
+        static const QChar asciiizeSource[];
+        static const QString asciiizeTarget[];
 
         IdSuggestions();
         ~IdSuggestions();
 
         static QStringList authorsLastName( BibTeX::Entry *entry );
         static QString normalizeText( const QString& text );
+        static QString asciiizeText( const QString& text );
         static int extractYear( BibTeX::Entry *entry );
         static QString extractTitle( BibTeX::Entry *entry );
         static QString translateToken( BibTeX::Entry *entry, const QString& token );
