@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2005 by Thomas Fischer                             *
+ *   Copyright (C) 2004-2009 by Thomas Fischer                             *
  *   fischer@unix-ag.uni-kl.de                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -45,7 +45,7 @@ namespace KBibTeX
 {
     QString IdSuggestionsWidget::exampleBibTeXEntry = "@Article{ dijkstra1983terminationdetect,\nauthor = {Edsger W. Dijkstra and W. H. J. Feijen and A. J. M. {van Gasteren}},\ntitle = {{Derivation of a Termination Detection Algorithm for Distributed Computations}},\njournal = {Information Processing Letters},\nvolume = 16,\nnumber = 5,\npages = {217--219},\nmonth = jun,\nyear = 1983\n}";
 
-    IdSuggestionComponent::IdSuggestionComponent( const QString& title, QWidget *parent ): QFrame( parent ), m_title( title ), m_parent( parent )
+    IdSuggestionComponent::IdSuggestionComponent( const QString& title, QWidget *parent ): QFrame( parent ), m_toBeDeleted( false ), m_title( title ), m_parent( parent )
     {
         setFrameShape( QFrame::Panel );
         setFrameShadow( QFrame::Sunken );
@@ -104,6 +104,7 @@ namespace KBibTeX
 
     void IdSuggestionComponent::slotDelete()
     {
+        m_toBeDeleted = true;
         emit deleted();
         delete this;
     }
@@ -121,10 +122,18 @@ namespace KBibTeX
         label->setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
         layout->addMultiCellWidget( label, 0, 0, 0, 2 );
 
-        m_checkBoxFirstAuthorOnly = new QCheckBox( i18n( "Use first author only" ), this );
-        layout->addMultiCellWidget( m_checkBoxFirstAuthorOnly, 1, 1, 0, 1 );
-        m_checkBoxFirstAuthorOnly->setChecked( text[0] == 'a' );
-        connect( m_checkBoxFirstAuthorOnly, SIGNAL( toggled( bool ) ), SIGNAL( modified() ) );
+        m_comboBoxWhichAuthors = new KComboBox( false, this );
+        layout->addMultiCellWidget( m_comboBoxWhichAuthors, 1, 1, 0, 1 );
+        m_comboBoxWhichAuthors->insertItem( i18n( "All authors" ) );
+        m_comboBoxWhichAuthors->insertItem( i18n( "First author only" ) );
+        m_comboBoxWhichAuthors->insertItem( i18n( "All but first author" ) );
+        switch ( text[0] )
+        {
+        case 'a': m_comboBoxWhichAuthors->setCurrentItem( 1 ); break;
+        case 'z': m_comboBoxWhichAuthors->setCurrentItem( 2 ); break;
+        default: m_comboBoxWhichAuthors->setCurrentItem( 0 );
+        }
+        connect( m_comboBoxWhichAuthors, SIGNAL( activated( const QString& ) ), SIGNAL( modified() ) );
 
         struct IdSuggestionTokenInfo info = IdSuggestions::evalToken( text.mid( 1 ) );
 
@@ -172,7 +181,15 @@ namespace KBibTeX
 
     QString IdSuggestionComponentAuthor::text() const
     {
-        QString result = m_checkBoxFirstAuthorOnly->isChecked() ? "a" : "A";
+        if ( m_toBeDeleted ) return QString::null;
+
+        QString result;
+        switch ( m_comboBoxWhichAuthors->currentItem() )
+        {
+        case 1: result = "a"; break;
+        case 2: result = "z"; break;
+        default: result = "A";
+        }
         if ( m_spinBoxLen->value() > 0 && m_spinBoxLen->value() <= 9 ) result.append( QString::number( m_spinBoxLen->value() ) );
         if ( m_comboBoxCasing->currentItem() == 1 ) result.append( "l" );
         else if ( m_comboBoxCasing->currentItem() == 2 ) result.append( "u" );
@@ -245,6 +262,8 @@ namespace KBibTeX
 
     QString IdSuggestionComponentTitle::text() const
     {
+        if ( m_toBeDeleted ) return QString::null;
+
         QString result = m_checkBoxRemoveSmallWords->isChecked() ? "T" : "t";
         if ( m_spinBoxLen->value() > 0 && m_spinBoxLen->value() <= 9 ) result.append( QString::number( m_spinBoxLen->value() ) );
         if ( m_comboBoxCasing->currentItem() == 1 ) result.append( "l" );
@@ -275,7 +294,7 @@ namespace KBibTeX
         m_comboBoxDigits->insertItem( i18n( "2 digits" ) );
         m_comboBoxDigits->insertItem( i18n( "4 digits" ) );
         m_comboBoxDigits->setCurrentItem( text[0] == 'y' ? 0 : 1 );
-        connect( m_comboBoxDigits, SIGNAL( textChanged( const QString& ) ), SIGNAL( modified() ) );
+        connect( m_comboBoxDigits, SIGNAL( activated( int ) ), SIGNAL( modified() ) );
 
         layout->setColStretch( 1, 1 );
         layout->setRowStretch( 2, 1 );
@@ -285,6 +304,7 @@ namespace KBibTeX
 
     QString IdSuggestionComponentYear::text() const
     {
+        if ( m_toBeDeleted ) return QString::null;
         return m_comboBoxDigits->currentItem() == 0 ? "y" : "Y";
     }
 
@@ -307,6 +327,7 @@ namespace KBibTeX
         label->setBuddy( m_lineEditInBetween );
         layout->addWidget( m_lineEditInBetween, 1, 1 );
         m_lineEditInBetween->setText( text.mid( 1 ) );
+        connect( m_lineEditInBetween, SIGNAL( textChanged( const QString& ) ), SIGNAL( modified() ) );
 
         layout->setColStretch( 1, 1 );
         layout->setRowStretch( 2, 1 );
@@ -316,6 +337,7 @@ namespace KBibTeX
 
     QString IdSuggestionComponentText::text() const
     {
+        if ( m_toBeDeleted ) return QString::null;
         return m_lineEditInBetween->text().isEmpty() ? QString::null : QString( "\"" ).append( m_lineEditInBetween->text() );
     }
 
@@ -349,7 +371,6 @@ namespace KBibTeX
 
         setupGUI();
         reset( formatStr );
-        updateExample();
     }
 
     IdSuggestionsWidget::~IdSuggestionsWidget()
@@ -407,17 +428,15 @@ namespace KBibTeX
             if ( component != NULL )
             {
                 ++m_componentCount;
-                connect( component, SIGNAL( moved() ), this, SLOT( componentsMoved() ) );
+                connect( component, SIGNAL( moved() ), this, SLOT( updateGUI() ) );
                 connect( component, SIGNAL( deleted() ), this, SLOT( componentDeleted() ) );
-                connect( component, SIGNAL( moved() ), this, SLOT( updateExample() ) );
-                connect( component, SIGNAL( deleted() ), this, SLOT( updateExample() ) );
                 connect( component, SIGNAL( modified() ), this, SLOT( updateExample() ) );
             }
         }
 
         m_listOfComponents->adjustSize();
         m_scrollViewComponents->verticalScrollBar()->adjustSize();
-        componentsMoved();
+        updateGUI();
         m_scrollViewComponents->resize( m_scrollViewComponents->width(), min( 384, m_listOfComponents->height() + 2 ) );
     }
 
@@ -487,18 +506,16 @@ namespace KBibTeX
 
             comp->show();
 
-            connect( comp, SIGNAL( moved() ), this, SLOT( componentsMoved() ) );
+            connect( comp, SIGNAL( moved() ), this, SLOT( updateGUI() ) );
             connect( comp, SIGNAL( deleted() ), this, SLOT( componentDeleted() ) );
-            connect( comp, SIGNAL( moved() ), this, SLOT( updateExample() ) );
-            connect( comp, SIGNAL( deleted() ), this, SLOT( updateExample() ) );
             connect( comp, SIGNAL( modified() ), this, SLOT( updateExample() ) );
             m_listOfComponents->adjustSize();
             m_scrollViewComponents->ensureVisible( 10, m_listOfComponents->height() - 2 );
-            componentsMoved();
+            updateGUI();
         }
     }
 
-    void IdSuggestionsWidget::componentsMoved()
+    void IdSuggestionsWidget::updateGUI()
     {
         QLayoutIterator it = m_listOfComponents->layout()->iterator();
         QLayoutItem *child = NULL;
@@ -525,18 +542,17 @@ namespace KBibTeX
         }
 
         if ( lastComponent != NULL )
-        {
             lastComponent->setEnableUpDown( m_componentCount > 1, FALSE );
-        }
 
         m_scrollViewComponents->updateGeometry();
         m_parent->enableButtonOK( m_componentCount > 0 );
+        updateExample();
     }
 
     void IdSuggestionsWidget::componentDeleted()
     {
         --m_componentCount;
-        componentsMoved();
+        updateGUI();
     }
 
     void IdSuggestionsWidget::updateExample()
