@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2004-2008 by Thomas Fischer                             *
+*   Copyright (C) 2004-2009 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -44,6 +44,8 @@
 #include <kstatusbar.h>
 #include <kglobalsettings.h>
 #include <kmessagebox.h>
+#include <kinputdialog.h>
+#include <kshortcut.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
 #include <kapplication.h>
@@ -210,7 +212,24 @@ bool KBibTeXPart::saveFile()
     if ( !url().isValid() || url().isEmpty() )
         return saveAs();
     else
-        return m_documentWidget->save( m_file );
+    {
+        /** make backup if defined by the user */
+        KBibTeX::Settings * settings = KBibTeX::Settings::self( NULL );
+        settings->createBackup( url(), widget() );
+
+        KTempFile tempBibFile = KTempFile( locateLocal( "tmp", "bibsave" ) );
+        tempBibFile.setAutoDelete( TRUE );
+        bool success =  m_documentWidget->save( tempBibFile.file() );
+        if ( success )
+        {
+            tempBibFile.close();
+            m_documentWidget->dirWatch().stopScan();
+            success = KIO::NetAccess::file_copy( KURL( tempBibFile.name() ), KURL( m_file ), -1, true, false, widget() );
+            m_documentWidget->dirWatch().startScan();
+        }
+
+        return success;
+    }
 }
 
 void KBibTeXPart::slotFileSaveAs()
@@ -221,13 +240,11 @@ void KBibTeXPart::slotFileSaveAs()
 bool KBibTeXPart::saveAs()
 {
     bool result = FALSE;
+    KBibTeX::Settings * settings = KBibTeX::Settings::self( NULL );
 
     QString startDir = ! url().isEmpty() ? url().url() : QDir::currentDirPath();
-    KURL saveURL = KFileDialog::getSaveURL( startDir, "*.bib|" + i18n( "BibTeX (*.bib)" ) + "\n*.ris|" + i18n( "Reference Manager (*.ris)" )
-#ifdef HAVE_LIBBIBUTILS
-                                            + "\n*.ref *.refer *.rfr *.txt|" + i18n( "EndNote (Refer format) (*.ref *.refer *.rfr *.txt)" ) + "\n*.isi *.cgi|" + i18n( "ISI Web of Knowledge (*.isi *.cgi)" )
-#endif
-                                            , widget() );
+    KURL saveURL = KFileDialog::getSaveURL( startDir, "*.bib|" + i18n( "BibTeX (*.bib)" ) + "\n*.ris|" + i18n( "Reference Manager (*.ris)" ) +
+                                            ( settings->external_xml2bibAvailable ? "\n*.ref *.refer *.rfr *.txt|" + i18n( "EndNote (Refer format) (*.ref *.refer *.rfr *.txt)" ) + "\n*.isi *.cgi|" + i18n( "ISI Web of Knowledge (*.isi *.cgi)" ) : "" ) + "\n*.xml|" + ( settings->external_xml2bibAvailable ? i18n( "DocBook 5 or MODS (*.xml)" ) : i18n( "DocBook 5 (*.xml)" ) ), widget() );
 
     if ( saveURL.isValid() && !saveURL.isEmpty() )
     {
@@ -247,17 +264,21 @@ bool KBibTeXPart::saveAs()
 
 void KBibTeXPart::slotFileExport()
 {
+    KBibTeX::Settings * settings = KBibTeX::Settings::self( NULL );
     QString startDir = ! url().isEmpty() ? url().url() : QDir::currentDirPath();
-    KURL exportURL = KFileDialog::getSaveURL( startDir, "*.pdf|" + i18n( "Portable Document File (*.pdf)" ) + "\n*.ps|" + i18n( "PostScript (*.ps)" ) + "\n*.ris|" + i18n( "Reference Manager (*.ris)" )
-#ifdef HAVE_LIBBIBUTILS
-                     + "\n*.ref *.refer *.rfr *.txt|" + i18n( "EndNote (Refer format) (*.ref *.refer *.rfr *.txt)" ) + "\n*.isi *.cgi|" + i18n( "ISI Web of Knowledge (*.isi *.cgi)" )
-#endif
-                     + "\n*.xml|" + i18n( "eXtended Markup Language (*.xml)" ) + "\n*.html|" + i18n( "Hypertext Markup Langage (*.html)" ) + "\n*.rtf|" + i18n( "Rich Text Format (*.rtf)" ), widget() );
+    KURL exportURL = KFileDialog::getSaveURL( startDir, "*.pdf|" + i18n( "Portable Document File (*.pdf)" ) + "\n*.ps|" + i18n( "PostScript (*.ps)" ) + "\n*.ris|" + i18n( "Reference Manager (*.ris)" ) + ( settings->external_xml2bibAvailable ?  "\n*.ref *.refer *.rfr *.txt|" + i18n( "EndNote (Refer format) (*.ref *.refer *.rfr *.txt)" ) + "\n*.isi *.cgi|" + i18n( "ISI Web of Knowledge (*.isi *.cgi)" ) : "" ) +   "\n*.xml|" + ( settings->external_xml2bibAvailable ? i18n( "DocBook 5 or MODS (*.xml)" ) :  i18n( "DocBook 5 (*.xml)" ) ) + "\n*.html|" + i18n( "Hypertext Markup Langage (*.html)" ) + "\n*.rtf|" + i18n( "Rich Text Format (*.rtf)" ), widget() );
 
     if ( exportURL.isValid() && !exportURL.isEmpty() )
     {
-        if ( KIO::NetAccess::exists( exportURL, FALSE, widget() ) && KMessageBox::warningContinueCancel( widget(), i18n( "A file named '%1' already exists. Are you sure you want to overwrite it?" ).arg( exportURL.filename() ), QString::null, i18n( "Overwrite" ) ) != KMessageBox::Continue )
-            return ;
+        if ( KIO::NetAccess::exists( exportURL, FALSE, widget() ) )
+        {
+            if ( KMessageBox::warningContinueCancel( widget(), i18n( "A file named '%1' already exists. Are you sure you want to overwrite it?" ).arg( exportURL.filename() ), QString::null, i18n( "Overwrite" ) ) != KMessageBox::Continue )
+                return ;
+
+            /** make backup if defined by the user */
+            KBibTeX::Settings * settings = KBibTeX::Settings::self( NULL );
+            settings->createBackup( exportURL, widget() );
+        }
 
         KTempFile tempBibFile = KTempFile( locateLocal( "tmp", "bibexport" ) );
         tempBibFile.setAutoDelete( TRUE );
@@ -268,18 +289,40 @@ void KBibTeXPart::slotFileExport()
             format = BibTeX::File::formatPDF;
         else if ( exportURL.fileName().endsWith( ".ps", FALSE ) )
             format = BibTeX::File::formatPS;
-#ifdef HAVE_LIBBIBUTILS
-        else if ( exportURL.fileName().endsWith( ".ref", FALSE ) || exportURL.fileName().endsWith( ".refer", FALSE ) || exportURL.fileName().endsWith( ".txt", FALSE ) || exportURL.fileName().endsWith( ".rfr", FALSE ) )
+        else if ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable && ( exportURL.fileName().endsWith( ".ref", FALSE ) || exportURL.fileName().endsWith( ".refer", FALSE ) || exportURL.fileName().endsWith( ".txt", FALSE ) || exportURL.fileName().endsWith( ".rfr", FALSE ) ) )
             format = BibTeX::File::formatEndNote;
-        else if ( exportURL.fileName().endsWith( ".isi", FALSE ) || exportURL.fileName().endsWith( ".cgi", FALSE ) )
+        else if ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable && ( exportURL.fileName().endsWith( ".isi", FALSE ) || exportURL.fileName().endsWith( ".cgi", FALSE ) ) )
             format = BibTeX::File::formatISI;
-#endif
         else if ( exportURL.fileName().endsWith( ".ris", FALSE ) )
             format = BibTeX::File::formatRIS;
         else if ( exportURL.fileName().endsWith( ".xml", FALSE ) )
-            format = BibTeX::File::formatXML;
+        {
+            QStringList options = QStringList::split( '|', ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable ? "DocBook5|MODS|internal XML" : "DocBook5|internal XML" ) );
+            bool ok = false;
+            QString answer = KInputDialog::getItem( i18n( "Choose file format" ), QString( i18n( "Choose file format of file '%1':" ) ).arg( exportURL.fileName() ), options, 0, false, &ok, widget() );
+            if ( ok && !answer.isNull() && answer == "DocBook5" )
+                format = BibTeX::File::formatDocBook5;
+            else if ( ok && !answer.isNull() && answer == "MODS" )
+                format = BibTeX::File::formatMODS;
+            else if ( ok && !answer.isNull() && answer == "internal XML" )
+                format = BibTeX::File::formatXML;
+        }
         else if ( exportURL.fileName().endsWith( ".html", FALSE ) )
             format = BibTeX::File::formatHTML;
+        else
+        {
+            QStringList options = QStringList::split( '|', ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable ? "BibTeX|EndNote|ISI|RIS" : "BibTeX|RIS" ) );
+            bool ok = false;
+            QString answer = KInputDialog::getItem( i18n( "Choose file format" ), QString( i18n( "Choose file format of file '%1':" ) ).arg( exportURL.fileName() ), options, 0, false, &ok, widget() );
+            if ( ok && !answer.isNull() && answer == "BibTeX" )
+                format = BibTeX::File::formatBibTeX;
+            else if ( ok && !answer.isNull() && answer == "EndNote" )
+                format = BibTeX::File::formatEndNote;
+            else if ( ok && !answer.isNull() && answer == "ISI" )
+                format = BibTeX::File::formatISI;
+            else if ( ok && !answer.isNull() && answer == "RIS" )
+                format = BibTeX::File::formatRIS;
+        }
 
         QStringList errorLog;
 
@@ -309,17 +352,17 @@ void KBibTeXPart::slotFileStatistics()
     m_documentWidget->showStatistics();
 }
 
+void KBibTeXPart::slotFileFindDups()
+{
+    m_documentWidget->findDuplicates();
+}
+
 void KBibTeXPart::slotFileMerge()
 {
+    KBibTeX::Settings * settings = KBibTeX::Settings::self( NULL );
     QString startDir = ! url().isEmpty() ? url().url() : QDir::currentDirPath();
     KURL mergeURL = KFileDialog::getOpenURL( startDir, QString( "*.bib *.ris" ) +
-#ifdef HAVE_LIBBIBUTILS
-                    " *.ref *.refer *.rfr *.txt *.isi *.cgi" +
-#endif
-                    "|" + i18n( "Supported Bibliographies" ) + "\n*.bib|" + i18n( "BibTeX (*.bib)" ) + "\n*.ris|" + i18n( "Reference Manager (*.ris)" )
-#ifdef HAVE_LIBBIBUTILS
-                    + "\n*.ref *.refer *.rfr *.txt|" + i18n( "EndNote (Refer format) (*.ref *.refer *.rfr *.txt)" ) + "\n*.isi *.cgi|" + i18n( "ISI Web of Knowledge (*.isi *.cgi)" )
-#endif
+                    ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable ? " *.xml *.ref *.refer *.rfr *.txt *.isi *.cgi" : "" ) + "|" + i18n( "Supported Bibliographies" ) + "\n*.bib|" + i18n( "BibTeX (*.bib)" ) + "\n*.ris|" + i18n( "Reference Manager (*.ris)" ) + ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable ? "\n*.ref *.refer *.rfr *.txt|" + i18n( "EndNote (Refer format) (*.ref *.refer *.rfr *.txt)" ) + "\n*.isi *.cgi|" + i18n( "ISI Web of Knowledge (*.isi *.cgi)" ) + "\n*.xml|" + i18n( "MODS or EndNote XML (*.xml)" ) : "" ) + "\n*|" + i18n( "All files (*.*)" )
                     , widget() );
 
     if ( !mergeURL.isValid() || mergeURL.isEmpty() )
@@ -381,6 +424,7 @@ void KBibTeXPart::setupActions()
         KStdAction::saveAs( this, SLOT( slotFileSaveAs() ), actionCollection() ) ->setToolTip( i18n( "Save the current file under a new filename" ) );
     }
     m_actionFileStatistics = new KAction( i18n( "Statistics..." ), CTRL + SHIFT + Key_I, this, SLOT( slotFileStatistics() ), actionCollection(), "file_statistics" );
+    m_actionFileFindDups = new KAction( i18n( "Find Duplicates..." ), CTRL + SHIFT + Key_D, this, SLOT( slotFileFindDups() ), actionCollection(), "file_finddups" );
     m_actionFileExport = new KAction( i18n( "Export..." ), SmallIconSet( "goto" ), CTRL + Key_E, this, SLOT( slotFileExport() ), actionCollection(), "file_export" );
     m_actionFileExport->setToolTip( i18n( "Export to a different file format" ) );
     m_actionFileMerge = new KAction( i18n( "Merge..." ), SmallIconSet( "reload" ), CTRL + Key_M, this, SLOT( slotFileMerge() ), actionCollection(), "file_merge" );
@@ -424,9 +468,16 @@ void KBibTeXPart::setupActions()
     m_actionViewDocument = new KActionMenu( i18n( "View Document" ), actionCollection(), "view_document" );
     m_actionViewDocument->setToolTip( i18n( "View the documents associated with this BibTeX entry" ) );
     m_actionViewDocument->setEnabled( FALSE );
+    m_actionViewFirstDocument = new KAction( i18n( "View Primary Document" ), 0, m_documentWidget, SLOT( slotViewFirstDocument() ), actionCollection(), "view_first_document" );
+    m_actionViewFirstDocument->setShortcut( Qt::Key_F4 );
+    m_actionViewDocumentOnlineRef = new KAction( i18n( "View Primary Online Reference" ), 0, m_documentWidget, SLOT( slotViewFirstDocumentsOnlineRef() ), actionCollection(), "view_first_documents_online_ref" );
+    m_actionViewDocumentOnlineRef->setShortcut( Qt::Key_F5 );
     m_actionAssignKeywords = new KActionMenu( i18n( "Assign Keywords" ), actionCollection(), "assign_keywords" );
     m_actionAssignKeywords->setToolTip( i18n( "Assign keywords to this entry" ) );
     m_actionAssignKeywords->setEnabled( FALSE );
+    m_actionNormalizeIds = new KAction( i18n( "Normalize Entry Ids" ), 0, m_documentWidget, SLOT( slotNormalizeIds() ), actionCollection( ), "normalize_ids" );
+    m_actionNormalizeIds->setToolTip( i18n( "Set entry ids as specified in the id suggestion settings" ) );
+    m_actionNormalizeIds->setEnabled( FALSE );
 
     m_actionPreferences = KStdAction::preferences( this, SLOT( slotPreferences() ), actionCollection() );
     m_actionPreferences->setToolTip( i18n( "Configure KBibTeX" ) );
@@ -551,7 +602,8 @@ void KBibTeXPart::slotUpdateMenu( int numSelectedItems )
     m_actionElementSendToLyX->setEnabled( numSelectedItems > 0 );
     m_actionMenuSearchWebsites->setEnabled( numSelectedItems == 1 );
     m_actionViewDocument->setEnabled( numSelectedItems == 1 && m_actionViewDocument->popupMenu() ->count() > 0 );
-    m_actionAssignKeywords->setEnabled( numSelectedItems == 1 );
+    m_actionAssignKeywords->setEnabled( numSelectedItems > 0 );
+    m_actionNormalizeIds->setEnabled( numSelectedItems > 0 && isReadWrite() );
 }
 
 void KBibTeXPart::slotUndoChanged( bool undoAvailable )
@@ -683,7 +735,7 @@ KInstance* KBibTeXPartFactory::instance()
 {
     if ( !s_instance )
     {
-        s_about = new KAboutData( "kbibtexpart", I18N_NOOP( "KBibTeXPart" ), "0.2.1" );
+        s_about = new KAboutData( "kbibtexpart", I18N_NOOP( "KBibTeXPart" ), "0.2.3" );
         s_about->addAuthor( "Thomas Fischer", 0, "fischer@unix-ag.uni-kl.de" );
         s_instance = new KInstance( s_about );
     }
