@@ -194,6 +194,10 @@ namespace KBibTeX
             idSuggestions_default = config->readNumEntry( "Default", -1 );
             idSuggestions_forceDefault = config->readBoolEntry( "ForceDefault", FALSE );
         }
+        idSuggestions_smallWords = config->readListEntry( "SmallWords" );
+        if ( idSuggestions_smallWords.count() == 0 )
+            idSuggestions_smallWords = QStringList::split( '|', "and|on|in|the|of|at|a|an|with|for|from" );
+        idSuggestions_smallWords.sort();
 
         config->setGroup( "UserDefinedInputFields" );
         QStringList names = config->readListEntry( "Names" );
@@ -278,6 +282,7 @@ namespace KBibTeX
         config->writeEntry( "FormatStrList", idSuggestions_formatStrList );
         config->writeEntry( "Default", idSuggestions_default );
         config->writeEntry( "ForceDefault", idSuggestions_forceDefault );
+        config->writeEntry( "SmallWords", idSuggestions_smallWords );
 
         config->setGroup( "UserDefinedInputFields" );
         QStringList names, labels, inputtype;
