@@ -25,11 +25,38 @@
 class QCheckBox;
 class QPushButton;
 class QComboBox;
+class QSlider;
 
-class KLineEdit;
+class KPushButton;
+class KURLRequester;
+class KListView;
 
 namespace KBibTeX
 {
+    class SettingsEditingPaths: public QWidget
+    {
+        Q_OBJECT
+    protected:
+        SettingsEditingPaths( QStringList& pathList, QWidget*parent = 0, const char *name = 0 );
+
+    public:
+        static bool execute( QWidget *parent, QStringList &pathList );
+
+    public slots:
+        void slotApply();
+        void slotTextChanged( const QString&text );
+        void slotAddDir();
+        void slotSelectionChanged();
+        void slotDelDir();
+
+    private:
+        QStringList &m_pathList;
+        KURLRequester *m_urlRequesterNewPath;
+        KPushButton *m_pushButtonAddDir;
+        KListView *m_listViewPathList;
+        KPushButton *m_pushButtonDelDir;
+    };
+
     class SettingsEditing : public QWidget
     {
         Q_OBJECT
@@ -59,10 +86,15 @@ namespace KBibTeX
         QPushButton *m_pushButtonSpecialFont;
         QFont m_specialFont;
         QComboBox *m_comboBoxNameOrder;
-        KLineEdit *m_lineEditDocumentSearchPath;
+        QStringList m_documentSearchPaths;
+        static const QChar pathListSeparator;
+        QSlider *m_sliderBarFindDuplicatesSensitivity;
 
         void updateFontData();
+        bool editPathList( QStringList &pathList );
+
+        const int m_findDuplicatesSensitivityMin, m_findDuplicatesSensitivityMax;
     };
 }
 
-#endif
+#endif // SETTINGSEDITING_H
