@@ -23,7 +23,7 @@
 #include <qwidget.h>
 
 class QLineEdit;
-class QPushButton;
+class KPushButton;
 class KListView;
 class QListViewItem;
 
@@ -50,11 +50,11 @@ namespace KBibTeX
         void updateGUI();
 
     private:
-        QPushButton *m_pushbuttonNew;
-        QPushButton *m_pushbuttonEdit;
-        QPushButton *m_pushbuttonDelete;
+        KPushButton *m_pushbuttonNew;
+        KPushButton *m_pushbuttonEdit;
+        KPushButton *m_pushbuttonDelete;
         KListView *m_listviewSearchURLs;
-        QPushButton *m_pushbuttonReset;
+        KPushButton *m_pushbuttonReset;
 
         int m_counter;
 
