@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2005 by Thomas Fischer                             *
+ *   Copyright (C) 2004-2009 by Thomas Fischer                             *
  *   fischer@unix-ag.uni-kl.de                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,6 +24,15 @@
 
 namespace KBibTeX
 {
+    /**
+     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
+    */
+    class WebQueryZMATHWidget : public WebQueryWidget
+    {
+        Q_OBJECT
+    public:
+        WebQueryZMATHWidget( QWidget *parent, const char *name = 0 );
+    };
 
     /**
      @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
@@ -35,12 +44,19 @@ namespace KBibTeX
         WebQueryZMATH( QWidget* parent );
         virtual ~WebQueryZMATH();
 
-        void query( const QString& searchTerm, int numberOfResults );
-        void cancelQuery() { /* nothing */ };
+        void query();
 
         QString title();
         QString disclaimer();
         QString disclaimerURL();
+
+        WebQueryWidget *widget();
+
+    protected:
+        void cancelQuery() { /* nothing */ };
+
+    private:
+        WebQueryZMATHWidget *m_widget;
     };
 
 }
